The Project can be explained as follows:

- Provide the chart details in an xml file.

- Provide the path to your xml in your settings.py.

- Make API calls to fetch the chart data as supported by Google Charts generated directly from your database. Or, you can just use our

- Javascript library to get the chart directly using an angular directive <hi-dash> without making any API calls manually.

- Use our APIs to generate reports of the charts in excel or pdf format.

- UI Ready Dashboard- Group reports in the xml file and see all the charts in a single page by just hitting a single url and writting zero lines of code.
